@@ -1,7 +1,7 @@
 // drumkv1widget_config.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2023, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -98,6 +98,8 @@ drumkv1widget_config::drumkv1widget_config (
 		m_ui.RandomizePercentSpinBox->setValue(pConfig->fRandomizePercent);
 		m_ui.UseGMDrumNamesCheckBox->setChecked(pConfig->bUseGMDrumNames);
 		// Custom display options (only for no-plugin forms)...
+		m_ui.CustomStyleThemeTextLabel->setEnabled(!bPlugin);
+		m_ui.CustomStyleThemeComboBox->setEnabled(!bPlugin);
 		resetCustomColorThemes(pConfig->sCustomColorTheme);
 		resetCustomStyleThemes(pConfig->sCustomStyleTheme);
 		// Load controllers database...
@@ -744,43 +746,44 @@ void drumkv1widget_config::accept (void)
 		}
 	}
 
-	if (m_iDirtyOptions > 0 && pConfig) {
+	if (m_iDirtyOptions > 0 && pConfig && m_pDrumkUi) {
 		// Save options...
 		pConfig->bProgramsPreview = m_ui.ProgramsPreviewCheckBox->isChecked();
 		pConfig->bUseNativeDialogs = m_ui.UseNativeDialogsCheckBox->isChecked();
 		pConfig->bDontUseNativeDialogs = !pConfig->bUseNativeDialogs;
-		pConfig->iKnobDialMode = m_ui.KnobDialModeComboBox->currentIndex();
-		drumkv1widget_dial::setDialMode(
-			drumkv1widget_dial::DialMode(pConfig->iKnobDialMode));
-		pConfig->iKnobEditMode = m_ui.KnobEditModeComboBox->currentIndex();
-		drumkv1widget_edit::setEditMode(
-			drumkv1widget_edit::EditMode(pConfig->iKnobEditMode));
-		const QString sOldCustomColorTheme = pConfig->sCustomColorTheme;
-		if (m_ui.CustomColorThemeComboBox->currentIndex() > 0)
-			pConfig->sCustomColorTheme = m_ui.CustomColorThemeComboBox->currentText();
-		else
-			pConfig->sCustomColorTheme.clear();
-		const QString sOldCustomStyleTheme = pConfig->sCustomStyleTheme;
-		if (m_ui.CustomStyleThemeComboBox->currentIndex() > 0)
-			pConfig->sCustomStyleTheme = m_ui.CustomStyleThemeComboBox->currentText();
-		else
-			pConfig->sCustomStyleTheme.clear();
+		pConfig->fRandomizePercent = float(m_ui.RandomizePercentSpinBox->value());
+		const int iOldKnobDialMode = pConfig->iKnobDialMode;
+		const int iOldKnobEditMode = pConfig->iKnobEditMode;
 		const int iOldFrameTimeFormat = pConfig->iFrameTimeFormat;
 		const bool bOldUseGMDrumNames = pConfig->bUseGMDrumNames;
+		pConfig->iKnobDialMode = m_ui.KnobDialModeComboBox->currentIndex();
+		pConfig->iKnobEditMode = m_ui.KnobEditModeComboBox->currentIndex();
 		pConfig->iFrameTimeFormat = m_ui.FrameTimeFormatComboBox->currentIndex();
-		pConfig->fRandomizePercent = float(m_ui.RandomizePercentSpinBox->value());
 		pConfig->bUseGMDrumNames = m_ui.UseGMDrumNamesCheckBox->isChecked();
 		int iNeedRestart = 0;
-		QWidget *pParentWidget = parentWidget();
-		if (pParentWidget) {
+		if (!m_pDrumkUi->isPlugin()) {
+			const QString sOldCustomStyleTheme = pConfig->sCustomStyleTheme;
+			if (m_ui.CustomStyleThemeComboBox->currentIndex() > 0)
+				pConfig->sCustomStyleTheme = m_ui.CustomStyleThemeComboBox->currentText();
+			else
+				pConfig->sCustomStyleTheme.clear();
 			if (pConfig->sCustomStyleTheme != sOldCustomStyleTheme) {
 				if (pConfig->sCustomStyleTheme.isEmpty()) {
 					++iNeedRestart;
 				} else {
-					pParentWidget->setStyle(
+					QApplication::setStyle(
 						QStyleFactory::create(pConfig->sCustomStyleTheme));
 				}
 			}
+		}
+		drumkv1widget *pParentWidget
+			= qobject_cast<drumkv1widget *> (parentWidget());
+		if (pParentWidget) {
+			const QString sOldCustomColorTheme = pConfig->sCustomColorTheme;
+			if (m_ui.CustomColorThemeComboBox->currentIndex() > 0)
+				pConfig->sCustomColorTheme = m_ui.CustomColorThemeComboBox->currentText();
+			else
+				pConfig->sCustomColorTheme.clear();
 			if (pConfig->sCustomColorTheme != sOldCustomColorTheme) {
 				if (pConfig->sCustomColorTheme.isEmpty()) {
 					++iNeedRestart;
@@ -791,11 +794,14 @@ void drumkv1widget_config::accept (void)
 						pParentWidget->setPalette(pal);
 				}
 			}
+			if (pConfig->iKnobDialMode != iOldKnobDialMode ||
+				pConfig->iKnobEditMode != iOldKnobEditMode ||
+				pConfig->iFrameTimeFormat != iOldFrameTimeFormat ||
+				(!pConfig->bUseGMDrumNames &&  bOldUseGMDrumNames) ||
+				( pConfig->bUseGMDrumNames && !bOldUseGMDrumNames)) {
+				pParentWidget->updateConfig();
+			}
 		}
-		if (pConfig->iFrameTimeFormat != iOldFrameTimeFormat)
-			++iNeedRestart;
-		if (!pConfig->bUseGMDrumNames && bOldUseGMDrumNames)
-			++iNeedRestart;
 		// Show restart message if needed...
  		if (iNeedRestart > 0) {
 			QMessageBox::information(this,
@@ -914,7 +920,8 @@ void drumkv1widget_config::resetCustomStyleThemes (
 		QStyleFactory::keys());
 
 	int iCustomStyleTheme = 0;
-	if (!sCustomStyleTheme.isEmpty()) {
+	if (!sCustomStyleTheme.isEmpty()
+		&& m_pDrumkUi && !m_pDrumkUi->isPlugin()) {
 		iCustomStyleTheme = m_ui.CustomStyleThemeComboBox->findText(
 			sCustomStyleTheme);
 		if (iCustomStyleTheme < 0)
